@@ -68,7 +68,7 @@ _PRIMARY_CONF = textwrap.dedent("""\
     picture-uri = 'file:///usr/share/backgrounds/edubuntu_default-primary.png'
 
     [org.gnome.shell:ubuntu]
-    favorite-apps = [ 'firefox_firefox.desktop', 'org.gnome.Calendar.desktop', 'org.gnome.Nautilus.desktop', 'tuxmath.desktop', 'org.kde.ktouch.desktop', 'org.gnome.Calculator.desktop', 'artha.desktop', 'libreoffice-writer.desktop', 'yelp.desktop' ]
+    favorite-apps = [ 'firefox_firefox.desktop', 'org.gnome.Calendar.desktop', 'org.gnome.Nautilus.desktop', 'org.gnome.Calculator.desktop', 'io.github.leolost2605.gradebook.desktop', 'libreoffice-writer.desktop', 'yelp.desktop' ]
 """)
 
 _SECONDARY_CONF = textwrap.dedent("""\
@@ -80,7 +80,7 @@ _SECONDARY_CONF = textwrap.dedent("""\
     picture-uri = 'file:///usr/share/backgrounds/edubuntu_default-secondary.png'
 
     [org.gnome.shell:ubuntu]
-    favorite-apps = [ 'firefox_firefox.desktop', 'thunderbird_thunderbird.desktop', 'org.gnome.Calendar.desktop', 'org.gnome.Nautilus.desktop', 'org.gnome.Calculator.desktop', 'org.gnome.Gnote.desktop', 'libreoffice-writer.desktop', 'yelp.desktop' ]
+    favorite-apps = [ 'firefox_firefox.desktop', 'thunderbird_thunderbird.desktop', 'org.gnome.Nautilus.desktop', 'org.gnome.Notes.desktopo', 'org.gnome.Calculator.desktop', 'io.github.leolost2605.gradebook.desktop', 'libreoffice-writer.desktop', 'yelp.desktop' ]
 """)
 
 GSCHEMA_CONTENTS = {
